// @flow

import React from 'react'
import _ from 'lodash'

console.log('_', _)

// import classes from './index.scss'

import { Column } from './Flexbox'
// import DayPicker from 'react-day-picker';

import Radio from './Radio'
import TextFieldArray from './TextFieldArray'
import TextField from './TextField'
import Tags from './Tags'
import validate from './validate'

type commonProps = {
  children: $ReactElement,
  input: Object,
  meta: Object,
  className: String
};

type selectProps = {
  ...commonProps,
  options: Array
};

const classes = {}

const Checkbox = ({ children, input, meta: { touched, error } }: commonProps) => {
  const showError = touched && error;

  return (
    <div>
      <label
        className={input.value ? classes.labelChecked : classes.label}
        htmlFor={`Checkbox_${input.name}`}
      >
        <input
          {...input}
          id={`Checkbox_${input.name}`}
          className={input.value ? classes.checkboxChecked : classes.checkbox}
          type="checkbox"
        />
        <span className={classes.text}>{children}</span>
      </label>
      {showError &&
        <span className={classes.error}>{error}</span>
      }
    </div>
  );
};

// class DatePicker extends React.Component {
//   static propTypes ={
//     input: PropTypes.object,
//     label: PropTypes.string,
//     meta: PropTypes.object
//   }

//   render () {
//     const { input, label, meta: { touched, error } } = this.props
//     const showError = touched && error
//     const id = `DatePicker_${input.name}`

//     return (
//       <div className={classes.textFieldContainer}>
//         <label htmlFor={id}>{label}</label>
//         <DayPicker
//           {...input}
//           onDayClick={input.onChange}
//           id={id}
//           format="dddd MMMM DD, YYYY"
//           selectedDays={input.value}
//         />
//         {showError &&
//           <span className={classes.error}>{error}</span>
//         }
//       </div>
//     )
//   }
// }

const Textarea = ({ label, input, meta: { touched, error } }: commonProps) => {
  const showError = touched && error;
  const fieldId = `Textarea_${input.name}`

  return (
    <div className={classes.textFieldContainer}>
      <label
        className={classes.text}
        htmlFor={fieldId}
      >
        {label}
      </label>
      <textarea
        {...input}
        id={fieldId}
        className={classes.textInput}
      >
        {input.value}
      </textarea>
      {showError &&
        <span className={classes.error}>{error}</span>
      }
    </div>
  )
}

const Select = ({ style, options, label, input, error, touched, capitalize: caps }: selectProps) => {
  const showError = touched && error

  return (
    <Column
      style={style}
    >
      <label htmlFor={input.name}>
        {label}
      </label>
      <select
        {...input}
        id={input.name}
      >
        {options.map((option, index) => {
          return (
            <option key={index} value={option}>
              {caps ? _.capitalize(option) : option}
            </option>
          )
        })}
      </select>
      {showError &&
        <span className={classes.error}>{error}</span>
      }
    </Column>
  )
}

export {
  Checkbox,
  TextField,
  Textarea,
  TextFieldArray,
  Select,
  // DatePicker,
  Radio,
  Tags,
  validate
}
